package com.soss.system.service.impl;

import com.soss.common.enums.ShopState;
import com.soss.common.utils.StringUtils;
import com.soss.system.domain.Shop;
import com.soss.system.mapper.ShopMapper;
import com.soss.system.utils.DistanceUtil;
import org.apache.commons.lang3.BooleanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

@Service
public class AppServiceImpl {
    @Autowired
    private ShopMapper shopMapper;

    /**
     * 授权了地理位置的用户都展示距离最近的营业中的店铺；
     * 未授权地理位置的用户都展示默认店铺，不管店铺是否营业中；
     */
    public Shop getShop(String lng, String lat, Boolean testFlag) {
        Shop shop = new Shop();
        boolean unAuthed = StringUtils.isEmpty(lng) || StringUtils.isEmpty(lat);
        if (unAuthed) {
            shop.setIsDefault(1L);
        } else if (BooleanUtils.isTrue(testFlag)) {
            shop.setStates(Arrays.asList(ShopState.TESTING.getState(), ShopState.OPEN.getState()));
        } else {
            shop.setState(ShopState.OPEN.getState());
        }

        List<Shop> shops = shopMapper.selectShopList(shop);
        if (CollectionUtils.isEmpty(shops)) {
            return new Shop();
        }

        if (unAuthed) {
            return shops.get(0);
        }

        shops.forEach(sp -> {
            double realDistance = DistanceUtil.getRealDistance(Double.parseDouble(lng), Double.parseDouble(lat),
                    Double.parseDouble(sp.getLng()), Double.parseDouble(sp.getLat()));
            sp.setRealDistance(realDistance);
            String distanceDesc = DistanceUtil.getDistanceDesc(realDistance);
            sp.setDistance(distanceDesc);
        });
        shops.sort(Comparator.comparing(Shop::getRealDistance));
        return shops.get(0);
    }
}
